@@ -4,7 +4,7 @@ TODO:
 """
 
 from .imports import *
-from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær, _dokumenter, _forside, _ledigeLokaler, _karakterer, _studieretning
+from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær, _dokumenter, _forside, _ledigeLokaler, _karakterer, _studieretning, _spørgeskema
 
 class sdk:
     def __init__(self, brugernavn, adgangskode, skoleId, base64Cookie=None):
@@ -78,8 +78,17 @@ class sdk:
     def ledigeLokaler(self):
         return _ledigeLokaler.ledigeLokaler(self)
 
-    def karakterer(self):
-        return _karakterer.karakterer(self)
+    def karakterer(self, mode="type"):
+        return _karakterer.karakterer(self, mode)
 
-    def studieretningspræsentation(self):
-        return _studieretning.studieretningspræsentation(self)
\ No newline at end of file
+    def studieretningspræsentation(self, elevId=None):
+        return _studieretning.studieretningspræsentation(self, elevId=elevId)
+
+    def spørgeskemaer(self):
+        return _spørgeskema.spørgeskemaer(self)
+
+    def opretMappe(self, folderName, folderComment, folderId):
+        return _dokumenter.opretMappe(self, folderName, folderComment, folderId)
+
+    def holdTilFag(self, holdId):
+        return _skema.holdTilFag(self, holdId)
\ No newline at end of file
